@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2012  Kouhei Sutou <kou@clear-code.com>
+# Copyright (C) 2012-2014  Kouhei Sutou <kou@clear-code.com>
 # Copyright (C) 2005-2008  Masao Mutoh
 #
 # License: Ruby's or LGPL
@@ -18,8 +18,9 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-require 'gettext/tools/xgettext'
-require 'gettext/tools/msgfmt'
-require 'gettext/tools/msginit'
-require 'gettext/tools/msgmerge'
-require 'gettext/mo'
+require "gettext/tools/xgettext"
+require "gettext/tools/msgfmt"
+require "gettext/tools/msginit"
+require "gettext/tools/msgmerge"
+require "gettext/tools/msgcat"
+require "gettext/mo"
