@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright (C) 2012  Haruka Yoshihara <yoshihara@clear-code.com>
-# Copyright (C) 2012  Kouhei Sutou <kou@clear-code.com>
+# Copyright (C) 2012-2014  Kouhei Sutou <kou@clear-code.com>
 #
 # License: Ruby's or LGPL
 #
@@ -51,7 +51,7 @@ module GetText
 
       bindtextdomain("gettext")
 
-      def initialize #:nodoc:
+      def initialize
         @input_file = nil
         @output_file = nil
         @locale = nil
@@ -59,6 +59,9 @@ module GetText
         @entry = nil
         @comment = nil
         @translator = nil
+        @set_translator = true
+        @translator_name = nil
+        @translator_eamil = nil
       end
 
       # Create .po file from .pot file, user's inputs and metadata.
@@ -80,7 +83,7 @@ module GetText
       private
       VERSION = GetText::VERSION
 
-      def parse_arguments(*arguments) #:nodoc:
+      def parse_arguments(*arguments)
         parser = OptionParser.new
         description = _("Create a new .po file from initializing .pot " +
                           "file with user's environment and input.")
@@ -109,6 +112,22 @@ module GetText
           @locale = loc
         end
 
+        parser.on("--[no-]translator",
+                  _("Whether set translator information or not"),
+                  _("(set)")) do |boolean|
+          @set_translator = boolean
+        end
+
+        parser.on("--translator-name=NAME",
+                  _("Use NAME as translator name")) do |name|
+          @translator_name = name
+        end
+
+        parser.on("--translator-email=EMAIL",
+                  _("Use EMAIL as translator email address")) do |email|
+          @translator_email = email
+        end
+
         parser.on("-h", "--help", _("Display this help and exit")) do
           puts(parser.help)
           exit(true)
@@ -137,7 +156,7 @@ module GetText
         else
           unless File.exist?(@input_file)
             raise(ValidationError,
-                  _("file '%s' does not exist." % @input_file))
+                  _("file '%s' does not exist.") % @input_file)
           end
         end
 
@@ -149,8 +168,9 @@ module GetText
 
         unless valid_locale?(language_tag)
           raise(ValidationError,
-                _("Locale '#{language_tag}' is invalid. " +
-                    "Please check if your specified locale is usable."))
+                _("Locale '%s' is invalid. " +
+                  "Please check if your specified locale is usable.") %
+                language_tag)
         end
         @locale = language_tag.to_simple.to_s
         @language = language_tag.language
@@ -158,7 +178,7 @@ module GetText
         @output_file ||= "#{@locale}.po"
         if File.exist?(@output_file)
           raise(ValidationError,
-                _("file '%s' has already existed." % @output_file))
+                _("file '%s' has already existed.") % @output_file)
         end
       end
 
@@ -168,7 +188,7 @@ module GetText
         Locale::Info.language_code?(language_tag.language)
       end
 
-      def replace_pot_header(pot) #:nodoc:
+      def replace_pot_header(pot)
         @entry = pot[""].msgstr
         @comment = pot[""].translator_comment
         @translator = translator_info
@@ -178,41 +198,44 @@ module GetText
 
         pot[""] = @entry
         pot[""].translator_comment = @comment
-        pot[""].flag = pot[""].flag.gsub(/\Afuzzy\z/, "")
+        pot[""].flags = pot[""].flags.reject do |flag|
+          flag == "fuzzy"
+        end
         pot
       end
 
       def translator_info
-        full_name = translator_full_name
-        mail = translator_mail
-        if not full_name.nil? and not mail.nil?
-          "#{full_name} <#{mail}>"
+        return nil unless @set_translator
+        name = translator_name
+        email = translator_email
+        if name and email
+          "#{name} <#{email}>"
         else
           nil
         end
       end
 
-      def translator_full_name
-        read_translator_full_name
+      def translator_name
+        @translator_name ||= read_translator_name
       end
 
-      def read_translator_full_name #:nodoc:
-        prompt(_("Please enter your full name"), guess_full_name)
+      def read_translator_name
+        prompt(_("Please enter your full name"), guess_translator_name)
       end
 
-      def guess_full_name
-        full_name = guess_full_name_from_password_entry
-        full_name ||= ENV["USERNAME"]
-        full_name
+      def guess_translator_name
+        name = guess_translator_name_from_password_entry
+        name ||= ENV["USERNAME"]
+        name
       end
 
-      def guess_full_name_from_password_entry
+      def guess_translator_name_from_password_entry
         password_entry = find_password_entry
         return nil if password_entry.nil?
 
-        full_name = password_entry.gecos.split(/,/).first.strip
-        full_name = nil if full_name.empty?
-        full_name
+        name = password_entry.gecos.split(/,/).first.strip
+        name = nil if name.empty?
+        name
       end
 
       def find_password_entry
@@ -221,15 +244,15 @@ module GetText
         nil
       end
 
-      def translator_mail
-        read_translator_mail
+      def translator_email
+        @translator_email ||= read_translator_email
       end
 
-      def read_translator_mail #:nodoc:
-        prompt(_("Please enter your email address"), guess_mail)
+      def read_translator_email
+        prompt(_("Please enter your email address"), guess_translator_email)
       end
 
-      def guess_mail
+      def guess_translator_email
         ENV["EMAIL"]
       end
 
@@ -263,7 +286,7 @@ module GetText
       EMAIL = "EMAIL@ADDRESS"
       FIRST_AUTHOR_KEY = /^FIRST AUTHOR <#{EMAIL}>, (\d+\.)$/
 
-      def replace_last_translator #:nodoc:
+      def replace_last_translator
         unless @translator.nil?
           @entry = @entry.gsub(LAST_TRANSLATOR_KEY, "\\1 #{@translator}")
         end
@@ -271,14 +294,14 @@ module GetText
 
       POT_REVISION_DATE_KEY = /^(PO-Revision-Date:).+/
 
-      def replace_pot_revision_date #:nodoc:
+      def replace_pot_revision_date
         @entry = @entry.gsub(POT_REVISION_DATE_KEY, "\\1 #{revision_date}")
       end
 
       LANGUAGE_KEY = /^(Language:).+/
       LANGUAGE_TEAM_KEY = /^(Language-Team:).+/
 
-      def replace_language #:nodoc:
+      def replace_language
         language_name = Locale::Info.get_language(@language).name
         @entry = @entry.gsub(LANGUAGE_KEY, "\\1 #{@locale}")
         @entry = @entry.gsub(LANGUAGE_TEAM_KEY, "\\1 #{language_name}")
@@ -287,7 +310,7 @@ module GetText
       PLURAL_FORMS =
         /^(Plural-Forms:) nplurals=INTEGER; plural=EXPRESSION;$/
 
-      def replace_plural_forms #:nodoc:
+      def replace_plural_forms
         plural_entry = plural_forms(@language)
         if PLURAL_FORMS =~ @entry
           @entry = @entry.gsub(PLURAL_FORMS, "\\1 #{plural_entry}\n")
@@ -296,7 +319,7 @@ module GetText
         end
       end
 
-      def plural_forms(language) #:nodoc:
+      def plural_forms(language)
         case language
         when "ja", "vi", "ko", /\Azh.*\z/
           nplural = "1"
@@ -348,7 +371,7 @@ module GetText
 
       DESCRIPTION_TITLE = /^SOME DESCRIPTIVE TITLE\.$/
 
-      def replace_description #:nodoc:
+      def replace_description
         language_name = Locale::Info.get_language(@language).name
         package_name = ""
         @entry.gsub(/Project-Id-Version: (.+?) .+/) do
@@ -362,7 +385,7 @@ module GetText
       YEAR_KEY = /^(FIRST AUTHOR <#{EMAIL}>,) YEAR\.$/
       LAST_TRANSLATOR_KEY = /^(Last-Translator:) FULL NAME <#{EMAIL}>$/
 
-      def replace_first_author #:nodoc:
+      def replace_first_author
         @comment = @comment.gsub(YEAR_KEY, "\\1 #{year}.")
         unless @translator.nil?
           @comment = @comment.gsub(FIRST_AUTHOR_KEY, "#{@translator}, \\1")
@@ -370,7 +393,7 @@ module GetText
       end
 
       COPYRIGHT_KEY = /^(Copyright \(C\)) YEAR (THE PACKAGE'S COPYRIGHT HOLDER)$/
-      def replace_copyright_year #:nodoc:
+      def replace_copyright_year
         @comment = @comment.gsub(COPYRIGHT_KEY, "\\1 #{year} \\2")
       end
 
