@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2012-2015  Kouhei Sutou <kou@clear-code.com>
+# Copyright (C) 2012-2020  Sutou Kouhei <kou@clear-code.com>
 # Copyright (C) 2010  Eddie Lau <tatonlto@gmail.com>
 #
 # License: Ruby's or LGPL
@@ -285,6 +285,17 @@ msgstr "bonjour"
         assert_equal("fuzzy", merged_po["hello"].flag)
       end
 
+      def test_fuzzy_matching_included_source
+        base_msgid = "hello"
+        new_msgid = base_msgid + ("!" * 10)
+        @po[base_msgid] = "bonjour"
+        @pot[new_msgid] = ""
+        merged_po = merge
+
+        assert_equal("bonjour", merged_po[new_msgid].msgstr)
+        assert_equal("fuzzy", merged_po[new_msgid].flag)
+      end
+
       def test_merged_entry_from_fuzzy_entry
         @po["hello"] = generate_entry(:msgid => "hello",
                                       :msgstr => "bonjuor",
@@ -352,7 +363,7 @@ EOC
   end
 
   class TestCommand < self
-    include GetTextTestUtils
+    include Helper::Tmpdir
 
     def setup
       @msgmerge = GetText::Tools::MsgMerge.new
@@ -411,7 +422,7 @@ msgid "Hello"
 msgstr ""
 
 #: hello.rb:3
-msgid "Hello World"
+msgid "Good-bye"
 msgstr ""
 EOP
     end
@@ -462,13 +473,15 @@ msgid "World"
 msgstr "Translated World"
 
 #: hello.rb:3
-msgid "Hello World"
+msgid "Good-bye"
 msgstr ""
 EOP
         end
       end
 
       class TestMessage < self
+        include Helper::Warning
+
         def po_content
           <<-PO
 #{po_header(@po_formatted_time, @po_formatted_time)}
@@ -480,7 +493,9 @@ msgstr "Translated World"
         end
 
         def test_merge_metadata
-          @msgmerge.run("--update", @po_file_path, @pot_file_path)
+          suppress_warning do
+            @msgmerge.run("--update", @po_file_path, @pot_file_path)
+          end
           assert_equal(<<-PO, File.read(@po_file_path))
 #{po_header(@pot_formatted_time, @po_formatted_time)}
 #: hello.rb:1
@@ -493,7 +508,7 @@ msgid "World"
 msgstr "Translated World"
 
 #: hello.rb:3
-msgid "Hello World"
+msgid "Good-bye"
 msgstr ""
           PO
         end
@@ -514,7 +529,7 @@ msgid "World"
 msgstr "Translated World"
 
 #: hello.rb:3
-msgid "Hello World"
+msgid "Good-bye"
 msgstr ""
         PO
       end
@@ -525,12 +540,12 @@ msgstr ""
                       @po_file_path, @pot_file_path)
         assert_equal(<<-PO, File.read(@po_file_path))
 #{po_header(@pot_formatted_time, @po_formatted_time)}
-#: hello.rb:1
-msgid "Hello"
+#: hello.rb:3
+msgid "Good-bye"
 msgstr ""
 
-#: hello.rb:3
-msgid "Hello World"
+#: hello.rb:1
+msgid "Hello"
 msgstr ""
 
 #: hello.rb:2
@@ -554,7 +569,7 @@ msgid "World"
 msgstr "Translated World"
 
 #: hello.rb:3
-msgid "Hello World"
+msgid "Good-bye"
 msgstr ""
         PO
       end
@@ -574,7 +589,7 @@ msgid "World"
 msgstr "Translated World"
 
 #: hello.rb:3
-msgid "Hello World"
+msgid "Good-bye"
 msgstr ""
         PO
       end
@@ -585,12 +600,12 @@ msgstr ""
                       @po_file_path, @pot_file_path)
         assert_equal(<<-PO, File.read(@po_file_path))
 #{po_header(@pot_formatted_time, @po_formatted_time)}
-#: hello.rb:1
-msgid "Hello"
+#: hello.rb:3
+msgid "Good-bye"
 msgstr ""
 
-#: hello.rb:3
-msgid "Hello World"
+#: hello.rb:1
+msgid "Hello"
 msgstr ""
 
 #: hello.rb:2
@@ -616,7 +631,7 @@ msgid "World"
 msgstr "Translated World"
 
 #: hello.rb:3
-msgid "Hello World"
+msgid "Good-bye"
 msgstr ""
         PO
       end
@@ -633,7 +648,7 @@ msgstr ""
 msgid "World"
 msgstr "Translated World"
 
-msgid "Hello World"
+msgid "Good-bye"
 msgstr ""
         PO
       end
@@ -647,7 +662,7 @@ msgid "Hello very long line! This line is very long. Yes! This line is very long
 msgstr ""
 
 #: hello.rb:3
-msgid "Hello World"
+msgid "Good-bye"
 msgstr ""
         POT
       end
@@ -655,8 +670,8 @@ msgstr ""
       def po_content
         <<-PO
 #: hello.rb:3
-msgid "Hello World"
-msgstr "Translated Hello World. This translation is very long. Yes! Very long translation!!!"
+msgid "Good-bye"
+msgstr "Translated Good-bye. This translation is very long. Yes! Very long translation!!!"
         PO
       end
 
@@ -671,10 +686,10 @@ msgid ""
 msgstr ""
 
 #: hello.rb:3
-msgid "Hello World"
+msgid "Good-bye"
 msgstr ""
-"Translated Hello World. This translation is very long. Yes! Very long translat"
-"ion!!!"
+"Translated Good-bye. This translation is very long. Yes! Very long translation"
+"!!!"
         PO
       end
 
@@ -690,10 +705,10 @@ msgid ""
 msgstr ""
 
 #: hello.rb:3
-msgid "Hello World"
+msgid "Good-bye"
 msgstr ""
-"Translated Hello World. This translation is very long. Yes! Very long "
-"translation!!!"
+"Translated Good-bye. This translation is very long. Yes! Very long tra"
+"nslation!!!"
         PO
       end
 
@@ -707,8 +722,8 @@ msgid "Hello very long line! This line is very long. Yes! This line is very long
 msgstr ""
 
 #: hello.rb:3
-msgid "Hello World"
-msgstr "Translated Hello World. This translation is very long. Yes! Very long translation!!!"
+msgid "Good-bye"
+msgstr "Translated Good-bye. This translation is very long. Yes! Very long translation!!!"
         PO
       end
     end
